Initialisation of the co-clusters by partitioning around medoids method.
init_pam(x, nu_j = NULL, a = NULL, K = K, G = G, akg = FALSE)A list of
nu_jnu_j.
mu_imu_i.
t_jgt_jg.
s_iks_ik.
pi_cpi.
rho_crho.
aa.
exp_utildeexp_utilde.
exp_logutildeexp_logutilde.
alpha_calpha.
The output of the cobiclust function.
a vector of . The length is equal to the number of colums.
an numeric.
an integer specifying the number of groups in rows.
an integer specifying the number of groups in columns.
a logical variable indicating whether to use a common dispersion parameter (akg = FALSE) or a dispersion parameter per cocluster (akg = TRUE).