Calculate the lower bound
lb_calculation(x = x, qu_param = qu_param, s_ik = s_ik, pi_c = pi_c,
t_jg = t_jg, rho_c = rho_c, mu_i = mu_i, nu_j = nu_j,
alpha_c = alpha_c, a = a, akg = TRUE)a list of 2 elements.
lbvalue of the lower bound.
entvalue of the entropy term.
a matrix of observations. Columns correspond to biological samples and rows to microorganisms.
s_ik.
pi_c.
t_jg.
rho_c.
mu_i.
nu_j.
a matrix the terms of interactions.
a.
a logical variable indicating whether to use a common dispersion parameter (akg = FALSE) or a dispersion parameter per cocluster (akg = TRUE).
qu.param.